[][src]Enum refinery_core::error::Kind

pub enum Kind {
    InvalidName,
    InvalidVersion,
    DivergentVersion(MigrationMigration),
    MissingVersion(Migration),
    InvalidMigrationPath(PathBufError),
    ConfigError(String),
    Connection(StringBox<dyn Error + Sync + Send>),
}

Enum listing possible errors from Refinery.

Variants

InvalidName

An Error from an invalid file name migration

InvalidVersion

An Error from an invalid version on a file name migration

DivergentVersion(MigrationMigration)

An Error from an divergent version, the applied version is different to the filesystem one

MissingVersion(Migration)

An Error from an divergent version, the applied version is missing on the filesystem

InvalidMigrationPath(PathBufError)

An Error from an invalid migrations path location

ConfigError(String)

An Error from an underlying database connection Error

Connection(StringBox<dyn Error + Sync + Send>)