Struct refinery_core::Migration
source · [−]pub struct Migration { /* private fields */ }Expand description
Represents a schema migration to be run on the database,
this struct is used by the embed_migrations! macro to gather migration files
and shouldn’t be needed by the user
Implementations
sourceimpl Migration
impl Migration
sourcepub fn unapplied(input_name: &str, sql: &str) -> Result<Migration, Error>
pub fn unapplied(input_name: &str, sql: &str) -> Result<Migration, Error>
Create an unapplied migration, name and version are parsed from the input_name, which must be named in the format (U|V){1}__{2}.rs where {1} represents the migration version and {2} the name.
sourcepub fn applied_on(&self) -> Option<&OffsetDateTime>
pub fn applied_on(&self) -> Option<&OffsetDateTime>
Get the timestamp from when the Migration was applied. None when unapplied.
Migrations returned from Runner::get_migrations() will always have None.