[−][src]Crate refinery_core
Re-exports
pub use crate::error::Error; |
pub use rusqlite; |
pub use postgres; |
pub use mysql; |
pub use tokio_postgres; |
pub use mysql_async; |
pub use tokio; |
Modules
| config | |
| error |
Structs
| Migration | Represents a schema migration to be run on the database,
this struct is used by the |
| Report | Struct that represents the report of the migration cycle,
a |
| Runner | Struct that represents the entrypoint to run the migrations,
an instance of this struct is returned by the |
Enums
| MigrationType | enum containing the migration types used to search for migrations either Rust Modules or Sql files |
| Target | An enum set that represents the target version up to which refinery should migrate, it is used by Runner |
Traits
| AsyncMigrate | |
| Migrate |
Functions
| find_migration_files | find migrations on file system recursively across directories given a location and MigrationType |